## LoadDensity
[![Downloads](https://static.pepy.tech/badge/je-load-density)](https://pepy.tech/project/je-load-density)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b3f05488c16a44959cbf0ec28d4c977c)](https://www.codacy.com/gh/JE-Chen/LoadDensity/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/LoadDensity&amp;utm_campaign=Badge_Grade)

[![LoadDensity Stable Python3.8](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_8.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_8.yml)

[![LoadDensity Stable Python3.9](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_9.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_9.yml)

[![LoadDensity Stable Python3.10](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_10.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_10.yml)

[![LoadDensity Stable Python3.11](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_11.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/LoadDensity/actions/workflows/stable_python3_11.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/loaddensity/badge/?version=latest)](https://loaddensity.readthedocs.io/en/latest/?badge=latest)

[LoadDensity Doc Click Here!](https://loaddensity.readthedocs.io/en/latest/)

---
> Project Kanban \
> https://github.com/orgs/Integration-Automation/projects/2/views/1 
> * Load automation.
> * Easy setup user template.
> * Load Density script.
> * Generate JSON/HTML/XML report.
> * 1 sec / thousands requests.
> * Fast spawn users.
> * Multi test on one task.
> * Specify test time.
> * OS Independent.
> * Remote automation support.
> * Project & Template support.
---

## install

```
pip install je_locust_wrapper
```

## require

```
python 3.8 or later  
```

>* Test on
>>    * windows 10 ~ 11
>>    * osx 10.5 ~ 11 big sur
>>    * ubuntu 20.0.4
>>    * raspberry pi 3B+
>>    * All test in test dir
>>    * 
### Architecture Diagram
![Architecture Diagram](architecture_diagram/LoadDnesity_Archirecture.drawio.png)